GaugeIndicator class
Configuration for the custom gauge indicator
Constructors
Properties
- animated → bool
-
Whether to animate the indicator
final
- fillColor → Color
-
The fill color of the indicator
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outlineColor → Color
-
The outline color of the indicator
final
- radius → double
-
The radius of the indicator
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double
-
The stroke width of the indicator outline
final
- useSegmentColorForOutline → bool
-
Whether to use the segment color for the outline
final
Methods
-
copyWith(
{double? radius, double? strokeWidth, Color? fillColor, Color? outlineColor, bool? useSegmentColorForOutline, bool? animated}) → GaugeIndicator - Creates a copy of this indicator with the given fields replaced
-
getOutlineColorForSegment(
Color segmentColor) → Color - Gets the outline color for a given segment
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited